/* A list of old or current members. */
div.fui-members {
}

div.fui-members a {
	color: #444;
	text-decoration: underline;
}
div.fui-members a:hover {
	color: #000;
}



div.fui-members h2 {
	clear: left;

	/* Need to use padding instead of margin because of float */
	padding-top: 30px;
	margin-top: 0;
}

/* Information + portrait */
div.fui-member-card {
	padding: 10px;
	float: left;
	position: relative;
	border: 1px solid #ddd;
	width: 325px;
	margin: 20px;
}
div.fui-members-old div.fui-member-card {
}

img.fui-member-portrait {
	float: left;
	display: block;
	border: 1px solid #444;
	max-width: 80px;
	max-height: 110px;
	margin: 0 10px 10px 0;
}

/* The information about a member */
div.fui-member-info {
	height: 110px;
	width: 237px;
	overflow: auto;
}

/* Name of member */
.fui-member-info h3 {
	margin: 0 0 10px 0;
	padding: 0;
	font-size: 1.2em;
	color: #555;
}

.fui-member-email {
	background-image: url("++resource++mail.png");
}

.fui-member-homepage {
	background-image: url("++resource++homepage.png");
}

.fui-member-homepage, .fui-member-email {
	background-repeat: no-repeat;
	background-position: 0 2px;
	padding-left: 20px;
	height: 18px;
	margin-bottom: 2px;
	padding-top: 1px;
}

.fui-member-description {
	margin-top: 5px;
	font-size: 0.8em;
	color: #555;
}

div.fui-member-more {
	text-align: right;
	height: 16px;
	margin-top: 7px;
}
div.fui-member-more a {
	font-weight: bold;
	color: #888;
	text-decoration: none;
}
